@@ -1,10 +1,13 @@
 import datetime
-
+import decimal
 
 from jija_orm import utils
 
 
 class Field:
+    # def __new__(cls, *args, **kwargs):
+    #     return super().__new__(*args, **kwargs)
+
     PYTHON_TYPE = NotImplemented
     SQL_TYPE = NotImplemented
     EQUAL_PARAMS = ('default', 'null')
@@ -30,7 +33,7 @@ class Field:
 
     @classmethod
     def _to_sql(cls, value):
-        raise NotImplementedError()
+        return value
 
     def get_type(self):
         return self.SQL_TYPE
@@ -54,19 +57,23 @@ class BooleanField(Field):
         return 'true' if value else 'false'
 
 
-class CharField(Field):
+class TextField(Field):
+    PYTHON_TYPE = str
+    SQL_TYPE = 'text'
+
+    @classmethod
+    def _to_sql(cls, value):
+        return f"'{value}'"
+
+
+class CharField(TextField):
     PYTHON_TYPE = str
-    SQL_TYPE = 'varchar'
     EQUAL_PARAMS = (*Field.EQUAL_PARAMS, 'max_length')
 
     def __init__(self, *, max_length, **kwargs):
         super().__init__(**kwargs)
         self.max_length = max_length
 
-    @classmethod
-    def _to_sql(cls, value):
-        return f"'{value}'"
-
     def get_type(self):
         return f'{self.SQL_TYPE}({self.max_length})'
 
@@ -75,9 +82,20 @@ class IntegerField(Field):
     PYTHON_TYPE = int
     SQL_TYPE = 'int4'
 
-    @classmethod
-    def _to_sql(cls, value):
-        return value
+
+class BigIntegerField(Field):
+    PYTHON_TYPE = int
+    SQL_TYPE = 'int8'
+
+
+class FloatField(Field):
+    PYTHON_TYPE = float
+    SQL_TYPE = 'float8'
+
+
+class DecimalField(Field):
+    PYTHON_TYPE = decimal.Decimal
+    SQL_TYPE = 'numeric'
 
 
 class DateField(Field):
@@ -101,10 +119,19 @@ class DatetimeField(Field):
 class RelatedField:
     def __init__(self, *, relation_to, on_delete, null=False):
         from jija_orm import models
-        if not issubclass(relation_to, models.Model):
-            raise ValueError('relation_to must be a model')
+        from jija_orm import config
+
+        if isinstance(relation_to, type) and issubclass(relation_to, models.Model):
+            self.__relation_to_class = relation_to
+            self.__relation_to = relation_to.get_name()
+
+        elif isinstance(relation_to, str):
+            self.__relation_to_class = config.JijaORM.get_model(relation_to)
+            self.__relation_to = self.__relation_to_class.get_name()
+
+        else:
+            raise ValueError('relation_to must be a model or string')
 
-        self.__relation_to = relation_to.get_name()
         self.__on_delete = on_delete
         self.__null = null
 
@@ -112,6 +139,10 @@ class RelatedField:
     def relation_to(self):
         return self.__relation_to
 
+    @property
+    def relation_to_class(self):
+        return self.__relation_to_class
+
     @property
     def on_delete(self):
         return self.__on_delete
@@ -164,8 +195,14 @@ def get_validator(value):
 
 SQL_TYPE_DICT = {
     BooleanField.SQL_TYPE: BooleanField,
-    IntegerField.SQL_TYPE: IntegerField,
+
     CharField.SQL_TYPE: CharField,
+    TextField.SQL_TYPE: TextField,
+
+    IntegerField.SQL_TYPE: IntegerField,
+    FloatField.SQL_TYPE: FloatField,
+    DecimalField.SQL_TYPE: DecimalField,
+
     DateField.SQL_TYPE: DateField,
-    DatetimeField.SQL_TYPE: DatetimeField
+    DatetimeField.SQL_TYPE: DatetimeField,
 }
