@@ -1,16 +1,19 @@
-import inspect
+import typing
+
+from jija_orm import executors
+from jija_orm.executors import query, operators
 
 
-from jija_orm.executors import query, executors, operators
+MODEL = typing.TypeVar('MODEL')
 
 
-class Model:
+class Model(typing.Generic[MODEL]):
     from jija_orm import fields
+
     id = fields.IntegerField(pk=True)
+    manager: query.QueryManager[typing.Type[MODEL]] = query.QueryManager
 
-    manager = query.QueryManager
-
-    def __init__(self, *, from_query=False, **kwargs):
+    def __init__(self: MODEL, *, from_query=False, **kwargs):
         self.__from_query = from_query
         self.__state = {}
 
@@ -24,10 +27,15 @@ class Model:
             self.__state[constraint] = value
             setattr(self, constraint, value)
 
+        if 'id' in kwargs:
+            for name, related_manager in self.get_related_managers().items():
+                setattr(self, name, related_manager.get_manager(self.__class__, self.id))
+
+
     @classmethod
-    def init_managers(cls, real_class=None):
+    def init_managers(cls, real_class: typing.Type[MODEL] = None):
         for name, attr in cls.__dict__.items():
-            if inspect.isclass(attr) and issubclass(attr, query.QueryManager):
+            if isinstance(attr, type) and issubclass(attr, query.QueryManager):
                 setattr(real_class, name, attr(real_class or cls))
 
         if hasattr(cls.__base__, 'init_managers'):
@@ -48,7 +56,7 @@ class Model:
         return model_fields
 
     @classmethod
-    def get_constraints(cls) -> dict[str, 'fields.RelatedField']:
+    def get_constraints(cls) -> typing.Dict[str, 'fields.RelatedField']:
         model_fields = {}
 
         for name, attr in cls.__dict__.items():
@@ -61,10 +69,20 @@ class Model:
 
         return model_fields
 
-    async def save(self):
-        # if self.__state['id'] is None:
-        #     return await self.insert()
+    @classmethod
+    def get_related_managers(cls) -> typing.Dict[str, query.RelatedManager]:
+        related_managers = {}
 
+        for name, attr in cls.__dict__.items():
+            if isinstance(attr, query.RelatedManager):
+                related_managers[name] = attr
+
+        if hasattr(cls.__base__, 'get_constraints'):
+            related_managers.update(cls.__base__.get_constraints())
+
+        return related_managers
+
+    async def save(self):
         to_update = {}
         for arg in self.__state:
             real_arg = getattr(self, arg)
@@ -92,27 +110,27 @@ class Model:
         return await executor.execute()
 
     @classmethod
-    def get_name(cls):
+    def get_name(cls) -> str:
         return cls.__name__.lower()
 
     @classmethod
-    def select(cls, *args, **kwargs):
+    def select(cls: typing.Type[MODEL], *args, **kwargs) -> query.QueryManager[MODEL]:
         return cls.manager.select(*args, **kwargs)
 
     @classmethod
-    def update(cls, **kwargs):
+    def update(cls: typing.Type[MODEL], **kwargs) -> query.QueryManager[MODEL]:
         return cls.manager.update(**kwargs)
 
     @classmethod
-    def where(cls, *args, **kwargs):
+    def where(cls: typing.Type[MODEL], *args, **kwargs) -> query.QueryManager[MODEL]:
         return cls.manager.where(*args, **kwargs)
 
     @classmethod
-    def multiple_create(cls, rows):
+    def multiple_create(cls: typing.Type[MODEL], rows) -> query.QueryManager[MODEL]:
         return cls.manager.multiple_insert(rows)
 
     @classmethod
-    def insert(cls, **kwargs):
+    def insert(cls: typing.Type[MODEL], **kwargs) -> query.QueryManager[MODEL]:
         return cls.manager.insert(**kwargs)
 
     def __repr__(self):
